LogLevel enum

LogLevel Controls the verbosity and location of logging

Inheritance
Available extensions

Values

debug → const LogLevel

debug level

info → const LogLevel

info for the user

warning → const LogLevel

warning - unusual

error → const LogLevel

error - a problem

none → const LogLevel

none - no level has been supplied

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on LogLevel, provided by the LogLevelExtension extension

name - the string representation
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.