Logger class

Logger a custom logger

Constructors

Logger({LogHandler logHandler = defaultLogHandler})
Constructors Logger
Logger.startWith(String configPath, {LogHandler? logHandler})
Logger.startWith - lets you initialize with a path and a handler

Properties

hashCode int
The hash code for this object.
no setterinherited
levelConfig Map<LogLevel, LogConfig>?
levelConfig a map of the types of logging
getter/setter pair
logHandler LogHandler
the function that will do the logging
final
notified bool
notified
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

log(String message, {LogLevel level = LogLevel.info}) → void
log - log a message of a particular level
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startWith(String configPath) → void
startWith - if unavailable at construction let's you set the configPath after you've constructed the log handler
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultLogHandler(String message, {LogLevel level = LogLevel.info}) → void
defaultLogHandler - provide a simple logger for writing to the screen