Model class

Model Is the base model for the classes that perform initialization of the two types of map input Is constructed from a Tile class and performs a run method to produce the bitmap and a save to persist it.

Implemented types

Constructors

Model(Tile tile)
Constructors Model paramater (Tile)

Properties

compatible ↔ Matrix3D<int>?
compatible
getter/setter pair
distribution List<double>
distribution
getter/setter pair
entropies List<double>
entropies
getter/setter pair
ground bool
ground
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
heuristic Heuristic
heuristic
getter/setter pair
mX int
mx the tile width
getter/setter pair
mY int
the tile height
getter/setter pair
N int
N
getter/setter pair
observed List<int>
observed
getter/setter pair
observedSoFar int
observed so far
getter/setter pair
periodic bool
periodice
getter/setter pair
propagator ↔ Matrix3D<int>?
propogator
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack List<Pair<int>>
stack
getter/setter pair
stacksize int
stacksize
getter/setter pair
startingEntropy double
startingEntropy
getter/setter pair
sumOfWeightLogWeights double
sumOfWeightLogWeights
getter/setter pair
sumOfWeights double
sumOfWeights
getter/setter pair
sumsOfOnes List<int>
sumOfOnes
getter/setter pair
sumsOfWeightLogWeights List<double>
sumOfWeightLogWeights
getter/setter pair
sumsOfWeights List<double>
sumOfWeights
getter/setter pair
T int
T
getter/setter pair
tileName String
tileName
getter/setter pair
wave ↔ Matrix<bool>?
the wave a matrix to guide the collapse
getter/setter pair
weightLogWeights List<double>
weightLogWeights
getter/setter pair
weights List<double>
weights
getter/setter pair

Methods

ban(int i, int t) → void
ban
clear() → void
clear
init() → void
init - setup the members to perform the wfc
nextUnobservedNode(Random random) int
nextUnobservedNode(closure) picks a random node to compare
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
observe(int node, Random random) → void
observe
propagate() bool
propogate
run(int seed, int limit) bool
run performs the wave function collapse
save(String path, Tile tile, int seed) → void
save should implement saving a bitmap to the path based on the tile, and a random seed to differentiate output files
override
toString() String
A string representation of this object.
inherited
weightedRandomSelection(List<double> distribution, double randomValue) int
Weighted random selection function

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

dx List<int>
dx
getter/setter pair
dy List<int>
dy
getter/setter pair
opposite List<int>
opposite
getter/setter pair