Tile class

Tile The description of the input bitmap to use, and what the wfc algorithm should do with it

Constructors

Tile()
Tile
Tile.fromJSON(Map<String, dynamic> tileJSONMap)
fromJSON

Properties

blackBackground bool
black background
getter/setter pair
category Category
what category of tile is this
getter/setter pair
ground bool
ground
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
height - usually the size
getter/setter pair
heuristic Heuristic
what heuristice to use
getter/setter pair
limit int
limit
getter/setter pair
N int
the dimensions in tiels
getter/setter pair
name String
the name of the tile
getter/setter pair
periodic bool
is it periodic
getter/setter pair
periodicInput bool
periodic input
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshots int
number of screenshots to make
getter/setter pair
size int
size - dimensions of the tile
getter/setter pair
subset String
subset
getter/setter pair
symmetry int
symmetry
getter/setter pair
textOutput bool
textOuptut to accompany the bitmap
getter/setter pair
width int
width - usually the size
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited