wfc library
The main entry point for the Wave Function Collapse package.
Provides access to essential models, heuristics, and logging utilities for procedural content generation.
Classes
- LogConfig
- LogConfig Takes the log type and relates it to a user defined output destincation defaults to the screen.
- Logger
- Logger a custom logger
- Model
- Model Is the base model for the classes that perform initialization of the two types of map input Is constructed from a Tile class and performs a run method to produce the bitmap and a save to persist it.
-
Result<
T> - Result Used to store a result that can be tested for pass or fail, and if failed provide an error explanation
- Saveable
- enforce saving with a path, tile, and seed
- Tile
- Tile The description of the input bitmap to use, and what the wfc algorithm should do with it
Enums
Extensions
- LogLevelExtension on LogLevel
- an extension to provide strings for the logging level
Properties
-
categoryFromString
↔ Map<
String, Category> -
get the category from a string - i.e. from reading xml
getter/setter pair
-
heuristicFromString
↔ Map<
String, Heuristic> -
get the heuristic from a string
getter/setter pair
Functions
-
createModel(
Tile tile, String basePath, {LogHandler? logHandler}) → Model - createModel factory method to create a model depending on the tile category : overlapping or simple_tiled
Typedefs
- LogHandler = void Function(String message, {LogLevel level})
- LogHandler function declaration