LogConfig class
LogConfig Takes the log type and relates it to a user defined output destincation defaults to the screen.
Constructors
- LogConfig({required bool enabled, required String outputType, String? filePath, Uri? serviceUri})
- LogConfig param - (bool) enable - enable the output parame - (String) outputType - the destination of the output param - (String) filePath - if a local drive - the path param - (Uri) serviceUri - if elsewhere the Uri
-
LogConfig.fromMap(Map<
String, dynamic> map) -
construct from the config map
factory
Properties
- enabled → bool
-
enabled
final
- filePath → String?
-
local location of output
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputType → String
-
type of outpuyt
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceUri → Uri?
-
URI
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited