Saveable class abstract
enforce saving with a path, tile, and seed
- Implementers
Constructors
- Saveable()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
String path, Tile tile, int seed) → void - save should implement saving a bitmap to the path based on the tile, and a random seed to differentiate output files
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited